==> apache-johnzon-1.2.21-src.tar.gz: apache-johnzon-1.2.21-src/johnzon-jsonb/src/main/java/org/apache/johnzon/jsonb/extension/JsonValueReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.johnzon.jsonb.extension;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.Reader;
import java.nio.charset.StandardCharsets;
import java.util.function.Supplier;

import javax.json.JsonStructure;

public class JsonValueReader<T> extends Reader implements Supplier<JsonStructure> {
    private final JsonStructure input;
    private ByteArrayInputStream fallbackDelegate;
    private T result;

    public JsonValueReader(final JsonStructure input) {
        this.input = input;
    }

    @Override
    public int read(final char[] cbuf, final int off, final int len) {
        if (fallbackDelegate == null) {
            fallbackDelegate = new ByteArrayInputStream(input.toString().getBytes(StandardCharsets.UTF_8));
        }
        return fallbackDelegate.read();
    }

    @Override
    public void close() throws IOException {
        if (fallbackDelegate != null) {
            fallbackDelegate.close();
        }
    }

    @Override
    public JsonStructure get() {
        return input;
    }

    @Deprecated
    public JsonStructure getInput() {
        return input;
    }

    @Deprecated
    public T getResult() {
        return result;
    }

    @Deprecated
    public void setResult(final T result) {
        this.result = result;
    }
}

==> apache-johnzon-2.0.0-src.tar.gz: apache-johnzon-2.0.0-src/johnzon-jsonb/src/main/java/org/apache/johnzon/jsonb/extension/JsonValueReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.johnzon.jsonb.extension;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.Reader;
import java.nio.charset.StandardCharsets;
import java.util.function.Supplier;

import jakarta.json.JsonStructure;

public class JsonValueReader<T> extends Reader implements Supplier<JsonStructure> {
    private final JsonStructure input;
    private ByteArrayInputStream fallbackDelegate;
    private T result;

    public JsonValueReader(final JsonStructure input) {
        this.input = input;
    }

    @Override
    public int read(final char[] cbuf, final int off, final int len) {
        if (fallbackDelegate == null) {
            fallbackDelegate = new ByteArrayInputStream(input.toString().getBytes(StandardCharsets.UTF_8));
        }
        return fallbackDelegate.read();
    }

    @Override
    public void close() throws IOException {
        if (fallbackDelegate != null) {
            fallbackDelegate.close();
        }
    }

    @Override
    public JsonStructure get() {
        return input;
    }

    @Deprecated
    public JsonStructure getInput() {
        return input;
    }

    @Deprecated
    public T getResult() {
        return result;
    }

    @Deprecated
    public void setResult(final T result) {
        this.result = result;
    }
}
